@@ -3,7 +3,7 @@
 
 use strict;
 use warnings;
-use DDP;
+use Data::Printer;
 
 use MetaCPAN::Client;
 
